vectorize Package
=================

:mod:`vectorize` Package
------------------------

.. automodule:: numba.vectorize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_common` Module
---------------------

.. automodule:: numba.vectorize._common
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`basic` Module
-------------------

.. automodule:: numba.vectorize.basic
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gufunc` Module
--------------------

.. automodule:: numba.vectorize.gufunc
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.vectorize.tests

